@@ -38,20 +38,20 @@
 GHDL offers two Python interfaces and a language server protocol service. All
 this is provided from a ``pyGHDL`` packages with four sub-packages:
 
-* ``pyGHDL.cli`` - Command line interface (CLI) applications.
-* ``pyGHDL.dom`` - A high-level API offering a document object model (DOM).
+* :mod:`pyGHDL.cli` - Command line interface (CLI) applications.
+* :mod:`pyGHDL.dom` - A high-level API offering a document object model (DOM).
   The underlying abstract VHDL language model is provided by :doc:`pyVHDLModel <vhdlmodel:index>`.
   The DOM is using ``libghdl`` for file analysis and parsing.
-* ``pyGHDL.libghdl`` - A low-level API directly interacting with the shared library ``libghdl....so``/``libghdl....dll``.
+* :mod:`pyGHDL.libghdl` - A low-level API directly interacting with the shared library ``libghdl....so``/``libghdl....dll``.
   This is a procedural and C-like interface. It comes with some Python generators for easier iterating linked lists.
-* ``pyGHDL.lsp`` - A :wikipedia:`language server protocol <Language_Server_Protocol>` (LSP)
+* :mod:`pyGHDL.lsp` - A :wikipedia:`language server protocol <Language_Server_Protocol>` (LSP)
   written in Python. The implementation offers an HTTPS service that can be used e.g. by editors and IDEs supporting LSP.
 """
 __author__ = "Tristan Gingold and contributors"
 __email__ = "tgingold@free.fr"
-__copyright__ = "2002-2021, Tristan Gingold and contributors"
+__copyright__ = "2002-2023, Tristan Gingold and contributors"
 __license__ = "GNU General Public License v2"
-__version__ = "2.0.0"
+__version__ = "3.0.0"
 __keywords__ = ["vhdl", "parser", "compiler", "simulator", "ghdl"]
 
 from pyTooling.Decorators import export
