@@ -13,7 +13,7 @@
 #
 # License:
 # ============================================================================
-#  Copyright (C) 2019-2021 Tristan Gingold
+#  Copyright (C) 2019-2022 Tristan Gingold
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -43,80 +43,65 @@ from typing import Iterable
 
 from pyTooling.Decorators import export
 
-from pyVHDLModel import ContextUnion, EntityOrSymbol
-from pyVHDLModel.SyntaxModel import (
-    LibraryClause as VHDLModel_LibraryClause,
-    UseClause as VHDLModel_UseClause,
-    ContextReference as VHDLModel_ContextReference,
-    Entity as VHDLModel_Entity,
-    Architecture as VHDLModel_Architecture,
-    Package as VHDLModel_Package,
-    PackageBody as VHDLModel_PackageBody,
-    PackageInstantiation as VHDLModel_PackageInstantiation,
-    Context as VHDLModel_Context,
-    Configuration as VHDLModel_Configuration,
-    Component as VHDLModel_Component,
-    GenericInterfaceItem,
-    PortInterfaceItem,
-    Name,
-    ConcurrentStatement,
-)
+from pyVHDLModel.Symbol import Symbol
+from pyVHDLModel.Instantiation import PackageInstantiation as VHDLModel_PackageInstantiation
+from pyVHDLModel.Interface import GenericInterfaceItem, PortInterfaceItem
+from pyVHDLModel.Concurrent import ConcurrentStatement
+from pyVHDLModel.DesignUnit import Context as VHDLModel_Context
+from pyVHDLModel.DesignUnit import Package as VHDLModel_Package
+from pyVHDLModel.DesignUnit import PackageBody as VHDLModel_PackageBody
+from pyVHDLModel.DesignUnit import Entity as VHDLModel_Entity
+from pyVHDLModel.DesignUnit import Architecture as VHDLModel_Architecture
+from pyVHDLModel.DesignUnit import Component as VHDLModel_Component
+from pyVHDLModel.DesignUnit import Configuration as VHDLModel_Configuration
+from pyVHDLModel.DesignUnit import LibraryClause as VHDLModel_LibraryClause
+from pyVHDLModel.DesignUnit import UseClause as VHDLModel_UseClause
+from pyVHDLModel.DesignUnit import ContextReference as VHDLModel_ContextReference
+from pyVHDLModel.DesignUnit import ContextUnion as VHDLModel_ContextUnion
 
 from pyGHDL.libghdl import utils
 from pyGHDL.libghdl._types import Iir
 from pyGHDL.libghdl.vhdl import nodes
 from pyGHDL.dom import DOMMixin, Position, DOMException
-from pyGHDL.dom._Utils import GetNameOfNode
-from pyGHDL.dom._Translate import (
-    GetGenericsFromChainedNodes,
-    GetPortsFromChainedNodes,
-    GetDeclaredItemsFromChainedNodes,
-    GetConcurrentStatementsFromChainedNodes,
-)
-from pyGHDL.dom.Names import SimpleName
-from pyGHDL.dom.Symbol import EntitySymbol
-
-
-__all__ = []
+from pyGHDL.dom._Utils import GetNameOfNode, GetDocumentationOfNode, GetPackageMemberSymbol, GetContextSymbol
+from pyGHDL.dom._Translate import GetGenericsFromChainedNodes, GetPortsFromChainedNodes
+from pyGHDL.dom._Translate import GetDeclaredItemsFromChainedNodes, GetConcurrentStatementsFromChainedNodes
+from pyGHDL.dom.Symbol import EntitySymbol, ContextReferenceSymbol, LibraryReferenceSymbol, PackageSymbol
 
 
 @export
 class LibraryClause(VHDLModel_LibraryClause, DOMMixin):
-    def __init__(self, libraryNode: Iir, names: Iterable[Name]):
-        super().__init__(names)
+    def __init__(self, libraryNode: Iir, symbols: Iterable[Symbol]):
+        super().__init__(symbols)
         DOMMixin.__init__(self, libraryNode)
 
 
 @export
 class UseClause(VHDLModel_UseClause, DOMMixin):
-    def __init__(self, useNode: Iir, names: Iterable[Name]):
-        super().__init__(names)
+    def __init__(self, useNode: Iir, symbols: Iterable[Symbol]):
+        super().__init__(symbols)
         DOMMixin.__init__(self, useNode)
 
     @classmethod
     def parse(cls, useNode: Iir):
-        from pyGHDL.dom._Translate import GetNameFromNode
-
-        uses = [GetNameFromNode(nodes.Get_Selected_Name(useNode))]
+        uses = [GetPackageMemberSymbol(nodes.Get_Selected_Name(useNode))]
         for use in utils.chain_iter(nodes.Get_Use_Clause_Chain(useNode)):
-            uses.append(GetNameFromNode(nodes.Get_Selected_Name(use)))
+            uses.append(GetPackageMemberSymbol(nodes.Get_Selected_Name(use)))
 
         return cls(useNode, uses)
 
 
 @export
 class ContextReference(VHDLModel_ContextReference, DOMMixin):
-    def __init__(self, contextNode: Iir, names: Iterable[Name]):
-        super().__init__(names)
+    def __init__(self, contextNode: Iir, symbols: Iterable[Symbol]):
+        super().__init__(symbols)
         DOMMixin.__init__(self, contextNode)
 
     @classmethod
     def parse(cls, contextNode: Iir):
-        from pyGHDL.dom._Translate import GetNameFromNode
-
-        contexts = [GetNameFromNode(nodes.Get_Selected_Name(contextNode))]
+        contexts = [GetContextSymbol(nodes.Get_Selected_Name(contextNode))]
         for context in utils.chain_iter(nodes.Get_Context_Reference_Chain(contextNode)):
-            contexts.append(GetNameFromNode(nodes.Get_Selected_Name(context)))
+            contexts.append(GetContextSymbol(nodes.Get_Selected_Name(context)))
 
         return cls(contextNode, contexts)
 
@@ -127,18 +112,20 @@ class Entity(VHDLModel_Entity, DOMMixin):
         self,
         node: Iir,
         identifier: str,
-        contextItems: Iterable[ContextUnion] = None,
+        contextItems: Iterable[VHDLModel_ContextUnion] = None,
         genericItems: Iterable[GenericInterfaceItem] = None,
         portItems: Iterable[PortInterfaceItem] = None,
         declaredItems: Iterable = None,
         statements: Iterable["ConcurrentStatement"] = None,
+        documentation: str = None,
     ):
-        super().__init__(identifier, contextItems, genericItems, portItems, declaredItems, statements)
+        super().__init__(identifier, contextItems, genericItems, portItems, declaredItems, statements, documentation)
         DOMMixin.__init__(self, node)
 
     @classmethod
-    def parse(cls, entityNode: Iir, contextItems: Iterable[ContextUnion]):
+    def parse(cls, entityNode: Iir, contextItems: Iterable[VHDLModel_ContextUnion]):
         name = GetNameOfNode(entityNode)
+        documentation = GetDocumentationOfNode(entityNode)
         generics = GetGenericsFromChainedNodes(nodes.Get_Generic_Chain(entityNode))
         ports = GetPortsFromChainedNodes(nodes.Get_Port_Chain(entityNode))
         declaredItems = GetDeclaredItemsFromChainedNodes(nodes.Get_Declaration_Chain(entityNode), "entity", name)
@@ -148,7 +135,7 @@ class Entity(VHDLModel_Entity, DOMMixin):
 
         # FIXME: read use clauses
 
-        return cls(entityNode, name, contextItems, generics, ports, declaredItems, statements)
+        return cls(entityNode, name, contextItems, generics, ports, declaredItems, statements, documentation)
 
 
 @export
@@ -157,20 +144,21 @@ class Architecture(VHDLModel_Architecture, DOMMixin):
         self,
         node: Iir,
         identifier: str,
-        entity: EntityOrSymbol,
-        contextItems: Iterable[ContextUnion] = None,
+        entity: EntitySymbol,
+        contextItems: Iterable[VHDLModel_ContextUnion] = None,
         declaredItems: Iterable = None,
         statements: Iterable["ConcurrentStatement"] = None,
+        documentation: str = None,
     ):
-        super().__init__(identifier, entity, contextItems, declaredItems, statements)
+        super().__init__(identifier, entity, contextItems, declaredItems, statements, documentation)
         DOMMixin.__init__(self, node)
 
     @classmethod
-    def parse(cls, architectureNode: Iir, contextItems: Iterable[ContextUnion]):
+    def parse(cls, architectureNode: Iir, contextItems: Iterable[VHDLModel_ContextUnion]):
         name = GetNameOfNode(architectureNode)
+        documentation = GetDocumentationOfNode(architectureNode)
         entityNameNode = nodes.Get_Entity_Name(architectureNode)
-        entityName = GetNameOfNode(entityNameNode)
-        entity = EntitySymbol(entityNameNode, SimpleName(entityNameNode, entityName))
+        entitySymbol = EntitySymbol(entityNameNode, GetNameOfNode(entityNameNode))
         declaredItems = GetDeclaredItemsFromChainedNodes(
             nodes.Get_Declaration_Chain(architectureNode), "architecture", name
         )
@@ -180,7 +168,7 @@ class Architecture(VHDLModel_Architecture, DOMMixin):
 
         # FIXME: read use clauses
 
-        return cls(architectureNode, name, entity, contextItems, declaredItems, statements)
+        return cls(architectureNode, name, entitySymbol, contextItems, declaredItems, statements, documentation)
 
 
 @export
@@ -191,17 +179,19 @@ class Component(VHDLModel_Component, DOMMixin):
         identifier: str,
         genericItems: Iterable[GenericInterfaceItem] = None,
         portItems: Iterable[PortInterfaceItem] = None,
+        documentation: str = None,
     ):
-        super().__init__(identifier, genericItems, portItems)
+        super().__init__(identifier, genericItems, portItems, documentation)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, componentNode: Iir):
         name = GetNameOfNode(componentNode)
+        documentation = GetDocumentationOfNode(componentNode)
         generics = GetGenericsFromChainedNodes(nodes.Get_Generic_Chain(componentNode))
         ports = GetPortsFromChainedNodes(nodes.Get_Port_Chain(componentNode))
 
-        return cls(componentNode, name, generics, ports)
+        return cls(componentNode, name, generics, ports, documentation)
 
 
 @export
@@ -210,16 +200,18 @@ class Package(VHDLModel_Package, DOMMixin):
         self,
         node: Iir,
         identifier: str,
-        contextItems: Iterable[ContextUnion] = None,
+        contextItems: Iterable[VHDLModel_ContextUnion] = None,
         genericItems: Iterable[GenericInterfaceItem] = None,
         declaredItems: Iterable = None,
+        documentation: str = None,
     ):
-        super().__init__(identifier, contextItems, genericItems, declaredItems)
+        super().__init__(identifier, contextItems, genericItems, declaredItems, documentation)
         DOMMixin.__init__(self, node)
 
     @classmethod
-    def parse(cls, packageNode: Iir, contextItems: Iterable[ContextUnion]):
+    def parse(cls, packageNode: Iir, contextItems: Iterable[VHDLModel_ContextUnion]):
         name = GetNameOfNode(packageNode)
+        documentation = GetDocumentationOfNode(packageNode)
 
         packageHeader = nodes.Get_Package_Header(packageNode)
         if packageHeader is not nodes.Null_Iir:
@@ -231,7 +223,7 @@ class Package(VHDLModel_Package, DOMMixin):
 
         # FIXME: read use clauses
 
-        return cls(packageNode, name, contextItems, generics, declaredItems)
+        return cls(packageNode, name, contextItems, generics, declaredItems, documentation)
 
 
 @export
@@ -239,21 +231,26 @@ class PackageBody(VHDLModel_PackageBody, DOMMixin):
     def __init__(
         self,
         node: Iir,
-        identifier: str,
-        contextItems: Iterable[ContextUnion] = None,
+        packageSymbol: PackageSymbol,
+        contextItems: Iterable[VHDLModel_ContextUnion] = None,
         declaredItems: Iterable = None,
+        documentation: str = None,
     ):
-        super().__init__(identifier, contextItems, declaredItems)
+        super().__init__(packageSymbol, contextItems, declaredItems, documentation)
         DOMMixin.__init__(self, node)
 
     @classmethod
-    def parse(cls, packageBodyNode: Iir, contextItems: Iterable[ContextUnion]):
-        name = GetNameOfNode(packageBodyNode)
-        declaredItems = GetDeclaredItemsFromChainedNodes(nodes.Get_Declaration_Chain(packageBodyNode), "package", name)
+    def parse(cls, packageBodyNode: Iir, contextItems: Iterable[VHDLModel_ContextUnion]):
+        packageName = GetNameOfNode(packageBodyNode)
+        packageSymbol = PackageSymbol(packageBodyNode, packageName)
+        documentation = GetDocumentationOfNode(packageBodyNode)
+        declaredItems = GetDeclaredItemsFromChainedNodes(
+            nodes.Get_Declaration_Chain(packageBodyNode), "package", packageName
+        )
 
         # FIXME: read use clauses
 
-        return cls(packageBodyNode, name, contextItems, declaredItems)
+        return cls(packageBodyNode, packageSymbol, contextItems, declaredItems, documentation)
 
 
 @export
@@ -262,15 +259,17 @@ class PackageInstantiation(VHDLModel_PackageInstantiation, DOMMixin):
         self,
         node: Iir,
         identifier: str,
-        uninstantiatedPackageName: Name,
+        uninstantiatedPackageName: Symbol,
         #        genericItems: List[GenericInterfaceItem] = None,
+        documentation: str = None,
     ):
-        super().__init__(identifier, uninstantiatedPackageName)
+        super().__init__(identifier, uninstantiatedPackageName, documentation)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, packageNode: Iir):
         name = GetNameOfNode(packageNode)
+        documentation = GetDocumentationOfNode(packageNode)
         uninstantiatedPackageName = nodes.Get_Uninstantiated_Package_Name(packageNode)
 
         # FIXME: read use clauses (does it apply here too?)
@@ -278,7 +277,7 @@ class PackageInstantiation(VHDLModel_PackageInstantiation, DOMMixin):
         # FIXME: read generic map
         # genericAssociations = GetGenericMapAspect(nodes.Get_Generic_Map_Aspect_Chain(instantiationNode))
 
-        return cls(packageNode, name, uninstantiatedPackageName)
+        return cls(packageNode, name, uninstantiatedPackageName, documentation)
 
 
 @export
@@ -287,10 +286,10 @@ class Context(VHDLModel_Context, DOMMixin):
         self,
         node: Iir,
         identifier: str,
-        libraryReferences: Iterable[LibraryClause] = None,
-        packageReferences: Iterable[UseClause] = None,
+        references: Iterable[VHDLModel_ContextUnion] = None,
+        documentation: str = None,
     ):
-        super().__init__(identifier, libraryReferences, packageReferences)
+        super().__init__(identifier, references, documentation)
         DOMMixin.__init__(self, node)
 
     @classmethod
@@ -298,13 +297,15 @@ class Context(VHDLModel_Context, DOMMixin):
         from pyGHDL.dom._Utils import GetIirKindOfNode
 
         name = GetNameOfNode(contextNode)
+        documentation = GetDocumentationOfNode(contextNode)
 
         items = []
         names = []
         for item in utils.chain_iter(nodes.Get_Context_Items(contextNode)):
             kind = GetIirKindOfNode(item)
             if kind is nodes.Iir_Kind.Library_Clause:
-                names.append(SimpleName(item, GetNameOfNode(item)))
+                libraryIdentifier = GetNameOfNode(item)
+                names.append(LibraryReferenceSymbol(item, libraryIdentifier))
                 if nodes.Get_Has_Identifier_List(item):
                     continue
 
@@ -312,33 +313,27 @@ class Context(VHDLModel_Context, DOMMixin):
                 names = []
             elif kind is nodes.Iir_Kind.Use_Clause:
                 items.append(UseClause.parse(item))
+            elif kind is nodes.Iir_Kind.Context_Reference:
+                items.append(ContextReference.parse(item))
             else:
                 pos = Position.parse(item)
-                raise DOMException(
-                    "Unknown context item kind '{kind}' in context at line {line}.".format(
-                        kind=kind.name, line=pos.Line
-                    )
-                )
+                raise DOMException(f"Unknown context item kind '{kind.name}' in context at line {pos.Line}.")
 
-        return cls(contextNode, name, items)
+        return cls(contextNode, name, items, documentation)
 
 
 @export
 class Configuration(VHDLModel_Configuration, DOMMixin):
-    def __init__(
-        self,
-        node: Iir,
-        identifier: str,
-        contextItems: Iterable[Context] = None,
-    ):
-        super().__init__(identifier, contextItems)
+    def __init__(self, node: Iir, identifier: str, contextItems: Iterable[Context] = None, documentation: str = None):
+        super().__init__(identifier, contextItems, documentation)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, configurationNode: Iir, contextItems: Iterable[Context]):
         name = GetNameOfNode(configurationNode)
+        documentation = GetDocumentationOfNode(configurationNode)
 
         # FIXME: read use clauses
         # FIXME: read specifications
 
-        return cls(configurationNode, name, contextItems)
+        return cls(configurationNode, name, contextItems, documentation)
