@@ -34,17 +34,17 @@ from typing import List, Union
 
 from pyTooling.Decorators import export
 
-from pyVHDLModel.SyntaxModel import (
+from pyVHDLModel.Base import ExpressionUnion
+from pyVHDLModel.Symbol import Symbol
+from pyVHDLModel.Expression import (
     UnaryExpression as VHDLModel_UnaryExpression,
-    BinaryExpression as VHDLModel_BinaryExpression,
-    InverseExpression as VHDLModel_InverseExpression,
-    IdentityExpression as VHDLModel_IdentityExpression,
     NegationExpression as VHDLModel_NegationExpression,
+    IdentityExpression as VHDLModel_IdentityExpression,
+    InverseExpression as VHDLModel_InverseExpression,
     AbsoluteExpression as VHDLModel_AbsoluteExpression,
-    SubExpression as VHDLModel_ParenthesisExpression,
     TypeConversion as VHDLModel_TypeConversion,
-    FunctionCall as VHDLModel_FunctionCall,
-    QualifiedExpression as VHDLModel_QualifiedExpression,
+    SubExpression as VHDLModel_ParenthesisExpression,
+    BinaryExpression as VHDLModel_BinaryExpression,
     RangeExpression as VHDLModel_RangeExpression,
     AscendingRangeExpression as VHDLModel_AscendingRangeExpression,
     DescendingRangeExpression as VHDLModel_DescendingRangeExpression,
@@ -64,29 +64,28 @@ from pyVHDLModel.SyntaxModel import (
     XnorExpression as VHDLModel_XnorExpression,
     EqualExpression as VHDLModel_EqualExpression,
     UnequalExpression as VHDLModel_UnequalExpression,
-    LessThanExpression as VHDLModel_LessThanExpression,
-    LessEqualExpression as VHDLModel_LessEqualExpression,
     GreaterThanExpression as VHDLModel_GreaterThanExpression,
     GreaterEqualExpression as VHDLModel_GreaterEqualExpression,
+    LessThanExpression as VHDLModel_LessThanExpression,
+    LessEqualExpression as VHDLModel_LessEqualExpression,
     MatchingEqualExpression as VHDLModel_MatchingEqualExpression,
     MatchingUnequalExpression as VHDLModel_MatchingUnequalExpression,
-    MatchingLessThanExpression as VHDLModel_MatchingLessThanExpression,
-    MatchingLessEqualExpression as VHDLModel_MatchingLessEqualExpression,
     MatchingGreaterThanExpression as VHDLModel_MatchingGreaterThanExpression,
     MatchingGreaterEqualExpression as VHDLModel_MatchingGreaterEqualExpression,
+    MatchingLessThanExpression as VHDLModel_MatchingLessThanExpression,
+    MatchingLessEqualExpression as VHDLModel_MatchingLessEqualExpression,
     ShiftRightLogicExpression as VHDLModel_ShiftRightLogicExpression,
     ShiftLeftLogicExpression as VHDLModel_ShiftLeftLogicExpression,
     ShiftRightArithmeticExpression as VHDLModel_ShiftRightArithmeticExpression,
     ShiftLeftArithmeticExpression as VHDLModel_ShiftLeftArithmeticExpression,
     RotateRightExpression as VHDLModel_RotateRightExpression,
     RotateLeftExpression as VHDLModel_RotateLeftExpression,
+    QualifiedExpression as VHDLModel_QualifiedExpression,
+    FunctionCall as VHDLModel_FunctionCall,
     SubtypeAllocation as VHDLModel_SubtypeAllocation,
     QualifiedExpressionAllocation as VHDLModel_QualifiedExpressionAllocation,
-    Aggregate as VHDLModel_Aggregate,
-    ExpressionUnion,
     AggregateElement,
-    SubtypeOrSymbol,
-    Symbol,
+    Aggregate as VHDLModel_Aggregate,
 )
 
 from pyGHDL.libghdl import utils
@@ -104,9 +103,6 @@ from pyGHDL.dom.Aggregates import (
 )
 
 
-__all__ = []
-
-
 class _ParseUnaryExpressionMixin:
     @classmethod
     def parse(cls, node: Iir) -> VHDLModel_UnaryExpression:
@@ -437,7 +433,7 @@ class RotateLeftExpression(VHDLModel_RotateLeftExpression, DOMMixin, _ParseBinar
 
 @export
 class QualifiedExpression(VHDLModel_QualifiedExpression, DOMMixin):
-    def __init__(self, node: Iir, subtype: SubtypeOrSymbol, operand: ExpressionUnion):
+    def __init__(self, node: Iir, subtype: Symbol, operand: ExpressionUnion):
         super().__init__(subtype, operand)
         DOMMixin.__init__(self, node)
 
@@ -520,9 +516,7 @@ class Aggregate(VHDLModel_Aggregate, DOMMixin):
                 else:
                     pos = Position.parse(item)
                     raise DOMException(
-                        "Unknown discete range kind '{kind}' in for...generate statement at line {line}.".format(
-                            kind=rangeKind.name, line=pos.Line
-                        )
+                        f"Unknown discrete range kind '{rangeKind.name}' in for...generate statement at line {pos.Line}."
                     )
 
                 choices.append(RangedAggregateElement(item, rng, value))
@@ -533,8 +527,6 @@ class Aggregate(VHDLModel_Aggregate, DOMMixin):
             elif kind == nodes.Iir_Kind.Choice_By_Others:
                 choices.append(OthersAggregateElement(item, value))
             else:
-                raise DOMException(
-                    "Unknown choice kind '{kind}' in aggregate '{aggr}'.".format(kind=kind.name, aggr=node)
-                )
+                raise DOMException(f"Unknown choice kind '{kind.name}' in aggregate '{node}'.")
 
         return cls(node, choices)
