@@ -34,6 +34,18 @@ from typing import List, Generator, Type
 
 from pyTooling.Decorators import export
 
+from pyVHDLModel import Name
+from pyVHDLModel.Base import ModelEntity, Direction, ExpressionUnion
+from pyVHDLModel.Symbol import Symbol
+from pyVHDLModel.Association import AssociationItem
+from pyVHDLModel.Interface import GenericInterfaceItem, PortInterfaceItem, ParameterInterfaceItem
+from pyVHDLModel.Type import BaseType
+from pyVHDLModel.Sequential import SequentialStatement
+from pyVHDLModel.Concurrent import ConcurrentStatement
+
+from pyGHDL.libghdl import utils, name_table
+from pyGHDL.libghdl._types import Iir
+from pyGHDL.libghdl.vhdl import nodes
 from pyGHDL.dom.Sequential import (
     IfStatement,
     ForLoopStatement,
@@ -45,30 +57,9 @@ from pyGHDL.dom.Sequential import (
     NullStatement,
     SequentialProcedureCall,
 )
-from pyVHDLModel.SyntaxModel import (
-    ConstraintUnion,
-    Direction,
-    ExpressionUnion,
-    SubtypeOrSymbol,
-    BaseType,
-    GenericInterfaceItem,
-    PortInterfaceItem,
-    ParameterInterfaceItem,
-    ModelEntity,
-    Name,
-    ConcurrentStatement,
-    SequentialStatement,
-    AssociationItem,
-)
 
-from pyGHDL.libghdl import utils, name_table
-from pyGHDL.libghdl._types import Iir
-from pyGHDL.libghdl.vhdl import nodes
 from pyGHDL.dom import Position, DOMException
-from pyGHDL.dom._Utils import (
-    GetNameOfNode,
-    GetIirKindOfNode,
-)
+from pyGHDL.dom._Utils import GetNameOfNode, GetIirKindOfNode
 from pyGHDL.dom.Names import (
     SimpleName,
     SelectedName,
@@ -173,9 +164,6 @@ from pyGHDL.dom.Misc import Alias
 from pyGHDL.dom.PSL import DefaultClock
 
 
-__all__ = []
-
-
 @export
 def GetNameFromNode(node: Iir) -> Name:
     kind = GetIirKindOfNode(node)
@@ -199,7 +187,7 @@ def GetNameFromNode(node: Iir) -> Name:
         prefixName = GetNameFromNode(nodes.Get_Prefix(node))
         return AllName(node, prefixName)
     else:
-        raise DOMException("Unknown name kind '{kind}'".format(kind=kind.name))
+        raise DOMException(f"Unknown name kind '{kind.name}'")
 
 
 def GetAssociations(node: Iir) -> List:
@@ -217,9 +205,7 @@ def GetAssociations(node: Iir) -> List:
             associations.append(expr)
         else:
             raise DOMException(
-                "Unknown association kind '{kind}' in array index/slice or function call '{node}'.".format(
-                    kind=kind.name, node=node
-                )
+                f"Unknown association kind '{kind.name}' in array index/slice or function call '{node}'."
             )
 
     return associations
@@ -228,7 +214,7 @@ def GetAssociations(node: Iir) -> List:
 @export
 def GetArrayConstraintsFromSubtypeIndication(
     subtypeIndication: Iir,
-) -> List[ConstraintUnion]:
+) -> List:
     constraints = []
     for constraint in utils.flist_iter(nodes.Get_Index_Constraint_List(subtypeIndication)):
         constraintKind = GetIirKindOfNode(constraint)
@@ -244,14 +230,7 @@ def GetArrayConstraintsFromSubtypeIndication(
         else:
             position = Position.parse(constraint)
             raise DOMException(
-                "Unknown constraint kind '{kind}' for constraint '{constraint}' in subtype indication '{indication}' at {file}:{line}:{column}.".format(
-                    kind=constraintKind.name,
-                    constraint=constraint,
-                    indication=subtypeIndication,
-                    file=position.Filename,
-                    line=position.Line,
-                    column=position.Column,
-                )
+                f"Unknown constraint kind '{constraintKind.name}' for constraint '{constraint}' in subtype indication '{subtypeIndication}' at {position}."
             )
 
     return constraints
@@ -280,13 +259,7 @@ def GetTypeFromNode(node: Iir) -> BaseType:
     else:
         position = Position.parse(typeDefinition)
         raise DOMException(
-            "GetTypeFromNode: Unknown type definition kind '{kind}' for type '{name}' at {file}:{line}:{column}.".format(
-                kind=kind.name,
-                name=typeName,
-                file=position.Filename,
-                line=position.Line,
-                column=position.Column,
-            )
+            f"GetTypeFromNode: Unknown type definition kind '{kind.name}' for type '{typeName}' at {position}."
         )
 
 
@@ -316,24 +289,18 @@ def GetAnonymousTypeFromNode(node: Iir) -> BaseType:
     else:
         position = Position.parse(typeDefinition)
         raise DOMException(
-            "GetAnonymousTypeFromNode: Unknown type definition kind '{kind}' for type '{name}' at {file}:{line}:{column}.".format(
-                kind=kind.name,
-                name=typeName,
-                file=position.Filename,
-                line=position.Line,
-                column=position.Column,
-            )
+            f"GetAnonymousTypeFromNode: Unknown type definition kind '{kind.name}' for type '{typeName}' at {position}."
         )
 
 
 @export
-def GetSubtypeIndicationFromNode(node: Iir, entity: str, name: str) -> SubtypeOrSymbol:
+def GetSubtypeIndicationFromNode(node: Iir, entity: str, name: str) -> Symbol:
     subtypeIndicationNode = nodes.Get_Subtype_Indication(node)
     return GetSubtypeIndicationFromIndicationNode(subtypeIndicationNode, entity, name)
 
 
 @export
-def GetSubtypeIndicationFromIndicationNode(subtypeIndicationNode: Iir, entity: str, name: str) -> SubtypeOrSymbol:
+def GetSubtypeIndicationFromIndicationNode(subtypeIndicationNode: Iir, entity: str, name: str) -> Symbol:
     if subtypeIndicationNode is nodes.Null_Iir:
         raise ValueError("Parameter 'subtypeIndicationNode' is 'Null_Iir'.")
 
@@ -349,17 +316,13 @@ def GetSubtypeIndicationFromIndicationNode(subtypeIndicationNode: Iir, entity: s
     elif kind == nodes.Iir_Kind.Array_Subtype_Definition:
         return GetCompositeConstrainedSubtypeFromNode(subtypeIndicationNode)
     else:
-        raise DOMException(
-            "Unknown kind '{kind}' for an subtype indication in a {entity} of `{name}`.".format(
-                kind=kind.name, entity=entity, name=name
-            )
-        )
+        raise DOMException(f"Unknown kind '{kind.name}' for an subtype indication in a {entity} of `{name}`.")
 
 
 @export
 def GetSimpleTypeFromNode(subtypeIndicationNode: Iir) -> SimpleSubtypeSymbol:
     subtypeName = GetNameFromNode(subtypeIndicationNode)
-    return SimpleSubtypeSymbol(subtypeIndicationNode, subtypeName)
+    return SimpleSubtypeSymbol(subtypeIndicationNode, str(subtypeName))  # XXX: hacked
 
 
 @export
@@ -371,7 +334,7 @@ def GetScalarConstrainedSubtypeFromNode(
     simpleTypeMark = SimpleName(typeMark, typeMarkName)
     rangeConstraint = nodes.Get_Range_Constraint(subtypeIndicationNode)
     r = GetRangeFromNode(rangeConstraint)
-    return ConstrainedScalarSubtypeSymbol(subtypeIndicationNode, simpleTypeMark, r)
+    return ConstrainedScalarSubtypeSymbol(subtypeIndicationNode, str(simpleTypeMark), r)  # XXX: hacked
 
 
 @export
@@ -383,11 +346,11 @@ def GetCompositeConstrainedSubtypeFromNode(
     simpleTypeMark = SimpleName(typeMark, typeMarkName)
 
     constraints = GetArrayConstraintsFromSubtypeIndication(subtypeIndicationNode)
-    return ConstrainedCompositeSubtypeSymbol(subtypeIndicationNode, simpleTypeMark, constraints)
+    return ConstrainedCompositeSubtypeSymbol(subtypeIndicationNode, str(simpleTypeMark), constraints)  # XXX: hacked
 
 
 @export
-def GetSubtypeFromNode(subtypeNode: Iir) -> SubtypeOrSymbol:
+def GetSubtypeFromNode(subtypeNode: Iir) -> Symbol:
     subtypeName = GetNameOfNode(subtypeNode)
 
     return Subtype(subtypeNode, subtypeName)
@@ -471,15 +434,7 @@ def GetExpressionFromNode(node: Iir) -> ExpressionUnion:
         cls = __EXPRESSION_TRANSLATION[kind]
     except KeyError:
         position = Position.parse(node)
-        raise DOMException(
-            "Unknown expression kind '{kind}' in expression '{expr}' at {file}:{line}:{column}.".format(
-                kind=kind.name,
-                expr=node,
-                file=position.Filename,
-                line=position.Line,
-                column=position.Column,
-            )
-        )
+        raise DOMException(f"Unknown expression kind '{kind.name}' in expression '{node}' at {position}.")
 
     return cls.parse(node)
 
@@ -495,13 +450,14 @@ def GetGenericsFromChainedNodes(
         GenericFunctionInterfaceItem,
     )
 
+    furtherIdentifiers = []
     generic = nodeChain
     while generic != nodes.Null_Iir:
         kind = GetIirKindOfNode(generic)
         if kind == nodes.Iir_Kind.Interface_Constant_Declaration:
             from pyGHDL.dom.InterfaceItem import GenericConstantInterfaceItem
 
-            genericConstant = GenericConstantInterfaceItem.parse(generic)
+            parseNode = generic
 
             # Lookahead for generics with multiple identifiers at once
             if nodes.Get_Has_Identifier_List(generic):
@@ -509,7 +465,7 @@ def GetGenericsFromChainedNodes(
                 for nextGeneric in utils.chain_iter(nextNode):
                     # Consecutive identifiers are found, if the subtype indication is Null
                     if nodes.Get_Subtype_Indication(nextGeneric) == nodes.Null_Iir:
-                        genericConstant.Identifiers.append(GetNameOfNode(nextGeneric))
+                        furtherIdentifiers.append(GetNameOfNode(nextGeneric))
                     else:
                         generic = nextGeneric
                         break
@@ -523,7 +479,8 @@ def GetGenericsFromChainedNodes(
             else:
                 generic = nodes.Get_Chain(generic)
 
-            yield genericConstant
+            yield GenericConstantInterfaceItem.parse(parseNode, furtherIdentifiers)
+            furtherIdentifiers.clear()
             continue
         else:
             if kind == nodes.Iir_Kind.Interface_Type_Declaration:
@@ -536,15 +493,7 @@ def GetGenericsFromChainedNodes(
                 yield GenericFunctionInterfaceItem.parse(generic)
             else:
                 position = Position.parse(generic)
-                raise DOMException(
-                    "Unknown generic kind '{kind}' in generic '{generic}' at {file}:{line}:{column}.".format(
-                        kind=kind.name,
-                        generic=generic,
-                        file=position.Filename,
-                        line=position.Line,
-                        column=position.Column,
-                    )
-                )
+                raise DOMException(f"Unknown generic kind '{kind.name}' in generic '{generic}' at {position}.")
 
         generic = nodes.Get_Chain(generic)
 
@@ -553,14 +502,14 @@ def GetGenericsFromChainedNodes(
 def GetPortsFromChainedNodes(
     nodeChain: Iir,
 ) -> Generator[PortInterfaceItem, None, None]:
-
+    furtherIdentifiers = []
     port = nodeChain
     while port != nodes.Null_Iir:
         kind = GetIirKindOfNode(port)
         if kind == nodes.Iir_Kind.Interface_Signal_Declaration:
             from pyGHDL.dom.InterfaceItem import PortSignalInterfaceItem
 
-            portSignal = PortSignalInterfaceItem.parse(port)
+            portToParse = port
 
             # Lookahead for ports with multiple identifiers at once
             if nodes.Get_Has_Identifier_List(port):
@@ -568,7 +517,7 @@ def GetPortsFromChainedNodes(
                 for nextPort in utils.chain_iter(nextNode):
                     # Consecutive identifiers are found, if the subtype indication is Null
                     if nodes.Get_Subtype_Indication(nextPort) == nodes.Null_Iir:
-                        portSignal.Identifiers.append(GetNameOfNode(nextPort))
+                        furtherIdentifiers.append(GetNameOfNode(nextPort))
                     else:
                         port = nextPort
                         break
@@ -582,56 +531,45 @@ def GetPortsFromChainedNodes(
             else:
                 port = nodes.Get_Chain(port)
 
-            yield portSignal
+            yield PortSignalInterfaceItem.parse(portToParse, furtherIdentifiers)
+            furtherIdentifiers.clear()
             continue
         else:
             position = Position.parse(port)
-            raise DOMException(
-                "Unknown port kind '{kind}' in port '{port}' at {file}:{line}:{column}.".format(
-                    kind=kind.name,
-                    port=port,
-                    file=position.Filename,
-                    line=position.Line,
-                    column=position.Column,
-                )
-            )
+            raise DOMException(f"Unknown port kind '{kind.name}' in port '{port}' at {position}.")
 
 
 @export
 def GetParameterFromChainedNodes(
     nodeChain: Iir,
 ) -> Generator[ParameterInterfaceItem, None, None]:
-
+    identifiers = []
     parameter = nodeChain
     while parameter != nodes.Null_Iir:
         kind = GetIirKindOfNode(parameter)
         if kind == nodes.Iir_Kind.Interface_Constant_Declaration:
             from pyGHDL.dom.InterfaceItem import ParameterConstantInterfaceItem
 
-            param = ParameterConstantInterfaceItem.parse(parameter)
+            parseMethod = ParameterConstantInterfaceItem.parse
+            parseNode = parameter
         elif kind == nodes.Iir_Kind.Interface_Variable_Declaration:
             from pyGHDL.dom.InterfaceItem import ParameterVariableInterfaceItem
 
-            param = ParameterVariableInterfaceItem.parse(parameter)
+            parseMethod = ParameterVariableInterfaceItem.parse
+            parseNode = parameter
         elif kind == nodes.Iir_Kind.Interface_Signal_Declaration:
             from pyGHDL.dom.InterfaceItem import ParameterSignalInterfaceItem
 
-            param = ParameterSignalInterfaceItem.parse(parameter)
+            parseMethod = ParameterSignalInterfaceItem.parse
+            parseNode = parameter
         elif kind == nodes.Iir_Kind.Interface_File_Declaration:
             from pyGHDL.dom.InterfaceItem import ParameterFileInterfaceItem
 
-            param = ParameterFileInterfaceItem.parse(parameter)
+            parseMethod = ParameterFileInterfaceItem.parse
+            parseNode = parameter
         else:
             position = Position.parse(parameter)
-            raise DOMException(
-                "Unknown parameter kind '{kind}' in parameter '{param}' at {file}:{line}:{column}.".format(
-                    kind=kind.name,
-                    param=parameter,
-                    file=position.Filename,
-                    line=position.Line,
-                    column=position.Column,
-                )
-            )
+            raise DOMException(f"Unknown parameter kind '{kind.name}' in parameter '{parameter}' at {position}.")
 
         # Lookahead for parameters with multiple identifiers at once
         if nodes.Get_Has_Identifier_List(parameter):
@@ -639,7 +577,7 @@ def GetParameterFromChainedNodes(
             for nextParameter in utils.chain_iter(nextNode):
                 # Consecutive identifiers are found, if the subtype indication is Null
                 if nodes.Get_Subtype_Indication(nextParameter) == nodes.Null_Iir:
-                    param.Identifiers.append(GetNameOfNode(nextParameter))
+                    identifiers.append(GetNameOfNode(nextParameter))
                 else:
                     parameter = nextParameter
                     break
@@ -653,7 +591,7 @@ def GetParameterFromChainedNodes(
         else:
             parameter = nodes.Get_Chain(parameter)
 
-        yield param
+        yield parseMethod(parseNode, identifiers)
 
 
 def GetMapAspect(mapAspect: Iir, cls: Type, entity: str) -> Generator[AssociationItem, None, None]:
@@ -679,11 +617,7 @@ def GetMapAspect(mapAspect: Iir, cls: Type, entity: str) -> Generator[Associatio
             yield cls(generic, OpenName(generic), formal)
         else:
             pos = Position.parse(generic)
-            raise DOMException(
-                "Unknown association kind '{kind}' in {entity} map at line {line}.".format(
-                    kind=kind.name, entity=entity, line=pos.Line
-                )
-            )
+            raise DOMException(f"Unknown association kind '{kind.name}' in {entity} map at line {pos.Line}.")
 
 
 def GetGenericMapAspect(
@@ -703,6 +637,7 @@ def GetParameterMapAspect(
 
 
 def GetDeclaredItemsFromChainedNodes(nodeChain: Iir, entity: str, name: str) -> Generator[ModelEntity, None, None]:
+    furtherIdentifiers = []
     item = nodeChain
     lastKind = None
     while item != nodes.Null_Iir:
@@ -710,23 +645,27 @@ def GetDeclaredItemsFromChainedNodes(nodeChain: Iir, entity: str, name: str) ->
         if kind == nodes.Iir_Kind.Constant_Declaration:
             from pyGHDL.dom.Object import Constant
 
-            obj = Constant.parse(item)
-
+            objectParseMethod = Constant.parse
+            objectItem = item
         elif kind == nodes.Iir_Kind.Variable_Declaration:
             from pyGHDL.dom.Object import SharedVariable
 
             if nodes.Get_Shared_Flag(item):
-                obj = SharedVariable.parse(item)
+                objectParseMethod = SharedVariable.parse
+                objectItem = item
             else:
-                obj = Variable.parse(item)
+                objectParseMethod = Variable.parse
+                objectItem = item
         elif kind == nodes.Iir_Kind.Signal_Declaration:
             from pyGHDL.dom.Object import Signal
 
-            obj = Signal.parse(item)
+            objectParseMethod = Signal.parse
+            objectItem = item
         elif kind == nodes.Iir_Kind.File_Declaration:
             from pyGHDL.dom.Object import File
 
-            obj = File.parse(item)
+            objectParseMethod = File.parse
+            objectItem = item
         else:
             if kind == nodes.Iir_Kind.Type_Declaration:
                 yield GetTypeFromNode(item)
@@ -752,14 +691,7 @@ def GetDeclaredItemsFromChainedNodes(nodeChain: Iir, entity: str, name: str) ->
                 else:
                     position = Position.parse(item)
                     raise DOMException(
-                        "Found unexpected function body '{functionName}' in {entity} '{name}' at {file}:{line}:{column}.".format(
-                            functionName=GetNameOfNode(item),
-                            entity=entity,
-                            name=name,
-                            file=position.Filename,
-                            line=position.Line,
-                            column=position.Column,
-                        )
+                        f"Found unexpected function body '{GetNameOfNode(item)}' in {entity} '{name}' at {position}."
                     )
             elif kind == nodes.Iir_Kind.Procedure_Declaration:
                 if nodes.Get_Has_Body(item):
@@ -776,14 +708,7 @@ def GetDeclaredItemsFromChainedNodes(nodeChain: Iir, entity: str, name: str) ->
                 else:
                     position = Position.parse(item)
                     raise DOMException(
-                        "Found unexpected procedure body '{functionName}' in {entity} '{name}' at {file}:{line}:{column}.".format(
-                            functionName=GetNameOfNode(item),
-                            entity=entity,
-                            name=name,
-                            file=position.Filename,
-                            line=position.Line,
-                            column=position.Column,
-                        )
+                        f"Found unexpected procedure body '{GetNameOfNode(item)}' in {entity} '{name}' at {position}."
                     )
             elif kind == nodes.Iir_Kind.Protected_Type_Body:
                 yield ProtectedTypeBody.parse(item)
@@ -814,27 +739,28 @@ def GetDeclaredItemsFromChainedNodes(nodeChain: Iir, entity: str, name: str) ->
 
                 yield PackageInstantiation.parse(item)
             elif kind == nodes.Iir_Kind.Configuration_Specification:
-                print("[NOT IMPLEMENTED] Configuration specification in {name}".format(name=name))
+                print(f"[NOT IMPLEMENTED] Configuration specification in {name}")
             elif kind == nodes.Iir_Kind.Psl_Default_Clock:
                 yield DefaultClock.parse(item)
             elif kind == nodes.Iir_Kind.Group_Declaration:
-                print("[NOT IMPLEMENTED] Group declaration in {name}".format(name=name))
+                print(f"[NOT IMPLEMENTED] Group declaration in {name}")
             elif kind == nodes.Iir_Kind.Group_Template_Declaration:
-                print("[NOT IMPLEMENTED] Group template declaration in {name}".format(name=name))
+                print(f"[NOT IMPLEMENTED] Group template declaration in {name}")
             elif kind == nodes.Iir_Kind.Disconnection_Specification:
-                print("[NOT IMPLEMENTED] Disconnect specification in {name}".format(name=name))
+                print(f"[NOT IMPLEMENTED] Disconnect specification in {name}")
+            elif kind == nodes.Iir_Kind.Nature_Declaration:
+                print(f"[NOT IMPLEMENTED] Nature declaration in {name}")
+            elif kind == nodes.Iir_Kind.Free_Quantity_Declaration:
+                print(f"[NOT IMPLEMENTED] Free quantity declaration in {name}")
+            elif kind == nodes.Iir_Kind.Across_Quantity_Declaration:
+                print(f"[NOT IMPLEMENTED] Across quantity declaration in {name}")
+            elif kind == nodes.Iir_Kind.Through_Quantity_Declaration:
+                print(f"[NOT IMPLEMENTED] Through quantity declaration in {name}")
+            elif kind == nodes.Iir_Kind.Terminal_Declaration:
+                print(f"[NOT IMPLEMENTED] Terminal declaration in {name}")
             else:
                 position = Position.parse(item)
-                raise DOMException(
-                    "Unknown declared item kind '{kind}' in {entity} '{name}' at {file}:{line}:{column}.".format(
-                        kind=kind.name,
-                        entity=entity,
-                        name=name,
-                        file=position.Filename,
-                        line=position.Line,
-                        column=position.Column,
-                    )
-                )
+                raise DOMException(f"Unknown declared item kind '{kind.name}' in {entity} '{name}' at {position}.")
 
             lastKind = None
             item = nodes.Get_Chain(item)
@@ -846,7 +772,7 @@ def GetDeclaredItemsFromChainedNodes(nodeChain: Iir, entity: str, name: str) ->
             for nextItem in utils.chain_iter(nextNode):
                 # Consecutive identifiers are found, if the subtype indication is Null
                 if nodes.Get_Subtype_Indication(nextItem) == nodes.Null_Iir:
-                    obj.Identifiers.append(GetNameOfNode(nextItem))
+                    furtherIdentifiers.append(GetNameOfNode(nextItem))
                 else:
                     item = nextItem
                     break
@@ -860,7 +786,8 @@ def GetDeclaredItemsFromChainedNodes(nodeChain: Iir, entity: str, name: str) ->
         else:
             item = nodes.Get_Chain(item)
 
-        yield obj
+        yield objectParseMethod(objectItem, furtherIdentifiers)
+        furtherIdentifiers.clear()
 
 
 def GetConcurrentStatementsFromChainedNodes(
@@ -870,7 +797,7 @@ def GetConcurrentStatementsFromChainedNodes(
         label = nodes.Get_Label(statement)
         label = name_table.Get_Name_Ptr(label) if label != nodes.Null_Iir else None
 
-        pos = Position.parse(statement)
+        position = Position.parse(statement)
 
         kind = GetIirKindOfNode(statement)
         if kind == nodes.Iir_Kind.Sensitized_Process_Statement:
@@ -883,21 +810,18 @@ def GetConcurrentStatementsFromChainedNodes(
             yield ConcurrentSimpleSignalAssignment.parse(statement, label)
         elif kind == nodes.Iir_Kind.Concurrent_Conditional_Signal_Assignment:
             print(
-                "[NOT IMPLEMENTED] Concurrent (conditional) signal assignment (label: '{label}') at line {line}".format(
-                    label=label, line=pos.Line
-                )
+                f"[NOT IMPLEMENTED] Concurrent (conditional) signal assignment (label: '{label}') at line {position.Line}"
             )
         elif kind == nodes.Iir_Kind.Concurrent_Selected_Signal_Assignment:
             print(
-                "[NOT IMPLEMENTED] Concurrent (selected) signal assignment (label: '{label}') at line {line}".format(
-                    label=label, line=pos.Line
-                )
+                f"[NOT IMPLEMENTED] Concurrent (selected) signal assignment (label: '{label}') at line {position.Line}"
             )
         elif kind == nodes.Iir_Kind.Concurrent_Procedure_Call_Statement:
             yield ConcurrentProcedureCall.parse(statement, label)
         elif kind == nodes.Iir_Kind.Component_Instantiation_Statement:
             instantiatedUnit = nodes.Get_Instantiated_Unit(statement)
             instantiatedUnitKind = GetIirKindOfNode(instantiatedUnit)
+
             if instantiatedUnitKind == nodes.Iir_Kind.Entity_Aspect_Entity:
                 yield EntityInstantiation.parse(statement, instantiatedUnit, label)
             elif instantiatedUnitKind == nodes.Iir_Kind.Entity_Aspect_Configuration:
@@ -906,13 +830,7 @@ def GetConcurrentStatementsFromChainedNodes(
                 yield ComponentInstantiation.parse(statement, instantiatedUnit, label)
             else:
                 raise DOMException(
-                    "Unknown instantiation kind '{kind}' in instantiation of label {label} at {file}:{line}:{column}.".format(
-                        kind=instantiatedUnitKind.name,
-                        label=label,
-                        file=pos.Filename,
-                        line=pos.Line,
-                        column=pos.Column,
-                    )
+                    f"Unknown instantiation kind '{instantiatedUnitKind.name}' in instantiation of label {label} at {position}."
                 )
         elif kind == nodes.Iir_Kind.Block_Statement:
             yield ConcurrentBlockStatement.parse(statement, label)
@@ -924,17 +842,10 @@ def GetConcurrentStatementsFromChainedNodes(
             yield ForGenerateStatement.parse(statement, label)
         elif kind == nodes.Iir_Kind.Psl_Assert_Directive:
             yield ConcurrentAssertStatement.parse(statement, label)
+        elif kind == nodes.Iir_Kind.Simple_Simultaneous_Statement:
+            print(f"[NOT IMPLEMENTED] Simple simultaneous statement (label: '{label}') at line {position.Line}")
         else:
-            raise DOMException(
-                "Unknown statement of kind '{kind}' in {entity} '{name}' at {file}:{line}:{column}.".format(
-                    kind=kind.name,
-                    entity=entity,
-                    name=name,
-                    file=pos.Filename,
-                    line=pos.Line,
-                    column=pos.Column,
-                )
-            )
+            raise DOMException(f"Unknown statement of kind '{kind.name}' in {entity} '{name}' at {position}.")
 
 
 def GetSequentialStatementsFromChainedNodes(
@@ -944,7 +855,7 @@ def GetSequentialStatementsFromChainedNodes(
         label = nodes.Get_Label(statement)
         label = name_table.Get_Name_Ptr(label) if label != nodes.Null_Iir else None
 
-        pos = Position.parse(statement)
+        position = Position.parse(statement)
         kind = GetIirKindOfNode(statement)
         if kind == nodes.Iir_Kind.If_Statement:
             yield IfStatement.parse(statement, label)
@@ -958,11 +869,7 @@ def GetSequentialStatementsFromChainedNodes(
             nodes.Iir_Kind.Variable_Assignment_Statement,
             nodes.Iir_Kind.Conditional_Variable_Assignment_Statement,
         ):
-            print(
-                "[NOT IMPLEMENTED] Variable assignment (label: '{label}') at line {line}".format(
-                    label=label, line=pos.Line
-                )
-            )
+            print(f"[NOT IMPLEMENTED] Variable assignment (label: '{label}') at line {position.Line}")
         elif kind == nodes.Iir_Kind.Wait_Statement:
             yield WaitStatement.parse(statement, label)
         elif kind == nodes.Iir_Kind.Procedure_Call_Statement:
@@ -974,16 +881,7 @@ def GetSequentialStatementsFromChainedNodes(
         elif kind == nodes.Iir_Kind.Null_Statement:
             yield NullStatement(statement, label)
         else:
-            raise DOMException(
-                "Unknown statement of kind '{kind}' in {entity} '{name}' at {file}:{line}:{column}.".format(
-                    kind=kind.name,
-                    entity=entity,
-                    name=name,
-                    file=pos.Filename,
-                    line=pos.Line,
-                    column=pos.Column,
-                )
-            )
+            raise DOMException(f"Unknown statement of kind '{kind.name}' in {entity} '{name}' at {position}.")
 
 
 def GetAliasFromNode(aliasNode: Iir):
