@@ -41,12 +41,18 @@ class Msgid(IntEnum):
     Warnid_Shared = 22
     Warnid_Hide = 23
     Warnid_Unused = 24
-    Warnid_Others = 25
-    Warnid_Pure = 26
-    Warnid_Analyze_Assert = 27
-    Warnid_Attribute = 28
-    Warnid_Useless = 29
-    Warnid_Static = 30
-    Msgid_Warning = 31
-    Msgid_Error = 32
-    Msgid_Fatal = 33
+    Warnid_Nowrite = 25
+    Warnid_Others = 26
+    Warnid_Pure = 27
+    Warnid_Analyze_Assert = 28
+    Warnid_Attribute = 29
+    Warnid_Useless = 30
+    Warnid_No_Assoc = 31
+    Warnid_Conformance = 32
+    Warnid_Unkept_Attribute = 33
+    Warnid_Unhandled_Attribute = 34
+    Warnid_Static = 35
+    Warnid_Elaboration = 36
+    Msgid_Warning = 37
+    Msgid_Error = 38
+    Msgid_Fatal = 39
