@@ -168,327 +168,343 @@ class fields(IntEnum):
     Designated_Entity = 48
     Formal = 49
     Actual = 50
-    Actual_Conversion = 51
-    Formal_Conversion = 52
-    Whole_Association_Flag = 53
-    Collapse_Signal_Flag = 54
-    Artificial_Flag = 55
-    Open_Flag = 56
-    After_Drivers_Flag = 57
-    We_Value = 58
-    Time = 59
-    Associated_Expr = 60
-    Associated_Block = 61
-    Associated_Chain = 62
-    Choice_Name = 63
-    Choice_Expression = 64
-    Choice_Range = 65
-    Same_Alternative_Flag = 66
-    Element_Type_Flag = 67
-    Architecture = 68
-    Block_Specification = 69
-    Prev_Block_Configuration = 70
-    Configuration_Item_Chain = 71
-    Attribute_Value_Chain = 72
-    Spec_Chain = 73
-    Value_Chain = 74
-    Attribute_Value_Spec_Chain = 75
-    Entity_Name = 76
-    Package = 77
-    Package_Body = 78
-    Instance_Package_Body = 79
-    Need_Body = 80
-    Macro_Expanded_Flag = 81
-    Need_Instance_Bodies = 82
-    Hierarchical_Name = 83
-    Vunit_Item_Chain = 84
-    Bound_Vunit_Chain = 85
-    Verification_Block_Configuration = 86
-    Block_Configuration = 87
-    Concurrent_Statement_Chain = 88
-    Chain = 89
-    Port_Chain = 90
-    Generic_Chain = 91
-    Type = 92
-    Subtype_Indication = 93
-    Discrete_Range = 94
-    Type_Definition = 95
-    Subtype_Definition = 96
-    Incomplete_Type_Declaration = 97
-    Interface_Type_Subprograms = 98
-    Nature_Definition = 99
-    Nature = 100
-    Subnature_Indication = 101
-    Mode = 102
-    Guarded_Signal_Flag = 103
-    Signal_Kind = 104
-    Base_Name = 105
-    Interface_Declaration_Chain = 106
-    Subprogram_Specification = 107
-    Sequential_Statement_Chain = 108
-    Simultaneous_Statement_Chain = 109
-    Subprogram_Body = 110
-    Overload_Number = 111
-    Subprogram_Depth = 112
-    Subprogram_Hash = 113
-    Impure_Depth = 114
-    Return_Type = 115
-    Implicit_Definition = 116
-    Uninstantiated_Subprogram_Name = 117
-    Default_Value = 118
-    Deferred_Declaration = 119
-    Deferred_Declaration_Flag = 120
-    Shared_Flag = 121
-    Design_Unit = 122
-    Block_Statement = 123
-    Signal_Driver = 124
-    Declaration_Chain = 125
-    File_Logical_Name = 126
-    File_Open_Kind = 127
-    Element_Position = 128
-    Use_Clause_Chain = 129
-    Context_Reference_Chain = 130
-    Inherit_Spec_Chain = 131
-    Selected_Name = 132
-    Type_Declarator = 133
-    Complete_Type_Definition = 134
-    Incomplete_Type_Ref_Chain = 135
-    Associated_Type = 136
-    Enumeration_Literal_List = 137
-    Entity_Class_Entry_Chain = 138
-    Group_Constituent_List = 139
-    Unit_Chain = 140
-    Primary_Unit = 141
-    Identifier = 142
-    Label = 143
-    Visible_Flag = 144
-    Range_Constraint = 145
-    Direction = 146
-    Left_Limit = 147
-    Right_Limit = 148
-    Left_Limit_Expr = 149
-    Right_Limit_Expr = 150
-    Parent_Type = 151
-    Simple_Nature = 152
-    Base_Nature = 153
-    Resolution_Indication = 154
-    Record_Element_Resolution_Chain = 155
-    Tolerance = 156
-    Plus_Terminal_Name = 157
-    Minus_Terminal_Name = 158
-    Plus_Terminal = 159
-    Minus_Terminal = 160
-    Magnitude_Expression = 161
-    Phase_Expression = 162
-    Power_Expression = 163
-    Simultaneous_Left = 164
-    Simultaneous_Right = 165
-    Text_File_Flag = 166
-    Only_Characters_Flag = 167
-    Is_Character_Type = 168
-    Nature_Staticness = 169
-    Type_Staticness = 170
-    Constraint_State = 171
-    Index_Subtype_List = 172
-    Index_Subtype_Definition_List = 173
-    Element_Subtype_Indication = 174
-    Element_Subtype = 175
-    Element_Subnature_Indication = 176
-    Element_Subnature = 177
-    Index_Constraint_List = 178
-    Array_Element_Constraint = 179
-    Has_Array_Constraint_Flag = 180
-    Has_Element_Constraint_Flag = 181
-    Elements_Declaration_List = 182
-    Owned_Elements_Chain = 183
-    Designated_Type = 184
-    Designated_Subtype_Indication = 185
-    Index_List = 186
-    Reference = 187
-    Nature_Declarator = 188
-    Across_Type_Mark = 189
-    Through_Type_Mark = 190
-    Across_Type_Definition = 191
-    Through_Type_Definition = 192
-    Across_Type = 193
-    Through_Type = 194
-    Target = 195
-    Waveform_Chain = 196
-    Guard = 197
-    Delay_Mechanism = 198
-    Reject_Time_Expression = 199
-    Force_Mode = 200
-    Has_Force_Mode = 201
-    Sensitivity_List = 202
-    Process_Origin = 203
-    Package_Origin = 204
-    Condition_Clause = 205
-    Break_Element = 206
-    Selector_Quantity = 207
-    Break_Quantity = 208
-    Timeout_Clause = 209
-    Postponed_Flag = 210
-    Callees_List = 211
-    Passive_Flag = 212
-    Resolution_Function_Flag = 213
-    Wait_State = 214
-    All_Sensitized_State = 215
-    Seen_Flag = 216
-    Pure_Flag = 217
-    Foreign_Flag = 218
-    Resolved_Flag = 219
-    Signal_Type_Flag = 220
-    Has_Signal_Flag = 221
-    Purity_State = 222
-    Elab_Flag = 223
-    Vendor_Library_Flag = 224
-    Configuration_Mark_Flag = 225
-    Configuration_Done_Flag = 226
-    Index_Constraint_Flag = 227
-    Hide_Implicit_Flag = 228
-    Assertion_Condition = 229
-    Report_Expression = 230
-    Severity_Expression = 231
-    Instantiated_Unit = 232
-    Generic_Map_Aspect_Chain = 233
-    Port_Map_Aspect_Chain = 234
-    Configuration_Name = 235
-    Component_Configuration = 236
-    Configuration_Specification = 237
-    Default_Binding_Indication = 238
-    Default_Configuration_Declaration = 239
-    Expression = 240
-    Conditional_Expression_Chain = 241
-    Allocator_Designated_Type = 242
-    Selected_Waveform_Chain = 243
-    Conditional_Waveform_Chain = 244
-    Guard_Expression = 245
-    Guard_Decl = 246
-    Guard_Sensitivity_List = 247
-    Signal_Attribute_Chain = 248
-    Block_Block_Configuration = 249
-    Package_Header = 250
-    Block_Header = 251
-    Uninstantiated_Package_Name = 252
-    Uninstantiated_Package_Decl = 253
-    Instance_Source_File = 254
-    Generate_Block_Configuration = 255
-    Generate_Statement_Body = 256
-    Alternative_Label = 257
-    Generate_Else_Clause = 258
-    Condition = 259
-    Else_Clause = 260
-    Parameter_Specification = 261
-    Parent = 262
-    Loop_Label = 263
-    Exit_Flag = 264
-    Next_Flag = 265
-    Component_Name = 266
-    Instantiation_List = 267
-    Entity_Aspect = 268
-    Default_Entity_Aspect = 269
-    Binding_Indication = 270
-    Named_Entity = 271
-    Referenced_Name = 272
-    Expr_Staticness = 273
-    Scalar_Size = 274
-    Error_Origin = 275
-    Operand = 276
-    Left = 277
-    Right = 278
-    Unit_Name = 279
-    Name = 280
-    Group_Template_Name = 281
-    Name_Staticness = 282
-    Prefix = 283
-    Signature_Prefix = 284
-    External_Pathname = 285
-    Pathname_Suffix = 286
-    Pathname_Expression = 287
-    In_Formal_Flag = 288
-    Slice_Subtype = 289
-    Suffix = 290
-    Index_Subtype = 291
-    Parameter = 292
-    Parameter_2 = 293
-    Parameter_3 = 294
-    Parameter_4 = 295
-    Attr_Chain = 296
-    Signal_Attribute_Declaration = 297
-    Actual_Type = 298
-    Actual_Type_Definition = 299
-    Association_Chain = 300
-    Individual_Association_Chain = 301
-    Subprogram_Association_Chain = 302
-    Aggregate_Info = 303
-    Sub_Aggregate_Info = 304
-    Aggr_Dynamic_Flag = 305
-    Aggr_Min_Length = 306
-    Aggr_Low_Limit = 307
-    Aggr_High_Limit = 308
-    Aggr_Others_Flag = 309
-    Aggr_Named_Flag = 310
-    Aggregate_Expand_Flag = 311
-    Association_Choices_Chain = 312
-    Case_Statement_Alternative_Chain = 313
-    Matching_Flag = 314
-    Choice_Staticness = 315
-    Procedure_Call = 316
-    Implementation = 317
-    Parameter_Association_Chain = 318
-    Method_Object = 319
-    Subtype_Type_Mark = 320
-    Subnature_Nature_Mark = 321
-    Type_Conversion_Subtype = 322
-    Type_Mark = 323
-    File_Type_Mark = 324
-    Return_Type_Mark = 325
-    Has_Disconnect_Flag = 326
-    Has_Active_Flag = 327
-    Is_Within_Flag = 328
-    Type_Marks_List = 329
-    Implicit_Alias_Flag = 330
-    Alias_Signature = 331
-    Attribute_Signature = 332
-    Overload_List = 333
-    Simple_Name_Identifier = 334
-    Simple_Name_Subtype = 335
-    Protected_Type_Body = 336
-    Protected_Type_Declaration = 337
-    Use_Flag = 338
-    End_Has_Reserved_Id = 339
-    End_Has_Identifier = 340
-    End_Has_Postponed = 341
-    Has_Label = 342
-    Has_Begin = 343
-    Has_End = 344
-    Has_Is = 345
-    Has_Pure = 346
-    Has_Body = 347
-    Has_Parameter = 348
-    Has_Component = 349
-    Has_Identifier_List = 350
-    Has_Mode = 351
-    Has_Class = 352
-    Has_Delay_Mechanism = 353
-    Suspend_Flag = 354
-    Is_Ref = 355
-    Is_Forward_Ref = 356
-    Psl_Property = 357
-    Psl_Sequence = 358
-    Psl_Declaration = 359
-    Psl_Expression = 360
-    Psl_Boolean = 361
-    PSL_Clock = 362
-    PSL_NFA = 363
-    PSL_Nbr_States = 364
-    PSL_Clock_Sensitivity = 365
-    PSL_EOS_Flag = 366
-    PSL_Abort_Flag = 367
-    Count_Expression = 368
-    Clock_Expression = 369
-    Default_Clock = 370
-    Foreign_Node = 371
+    Open_Actual = 51
+    Actual_Conversion = 52
+    Formal_Conversion = 53
+    Whole_Association_Flag = 54
+    Collapse_Signal_Flag = 55
+    Artificial_Flag = 56
+    Open_Flag = 57
+    After_Drivers_Flag = 58
+    We_Value = 59
+    Time = 60
+    Associated_Expr = 61
+    Associated_Block = 62
+    Associated_Chain = 63
+    Choice_Name = 64
+    Choice_Expression = 65
+    Choice_Range = 66
+    Same_Alternative_Flag = 67
+    Element_Type_Flag = 68
+    Architecture = 69
+    Block_Specification = 70
+    Prev_Block_Configuration = 71
+    Configuration_Item_Chain = 72
+    Attribute_Value_Chain = 73
+    Spec_Chain = 74
+    Value_Chain = 75
+    Attribute_Value_Spec_Chain = 76
+    Entity_Name = 77
+    Package = 78
+    Package_Body = 79
+    Instance_Package_Body = 80
+    Need_Body = 81
+    Macro_Expanded_Flag = 82
+    Need_Instance_Bodies = 83
+    Hierarchical_Name = 84
+    Vunit_Item_Chain = 85
+    Bound_Vunit_Chain = 86
+    Verification_Block_Configuration = 87
+    Block_Configuration = 88
+    Concurrent_Statement_Chain = 89
+    Chain = 90
+    Port_Chain = 91
+    Generic_Chain = 92
+    Type = 93
+    Subtype_Indication = 94
+    Discrete_Range = 95
+    Type_Definition = 96
+    Subtype_Definition = 97
+    Incomplete_Type_Declaration = 98
+    Interface_Type_Subprograms = 99
+    Interface_Type_Definition = 100
+    Nature_Definition = 101
+    Nature = 102
+    Subnature_Indication = 103
+    Reference_Terminal_Flag = 104
+    Mode = 105
+    Guarded_Signal_Flag = 106
+    Signal_Kind = 107
+    Base_Name = 108
+    Interface_Declaration_Chain = 109
+    Default_Subprogram = 110
+    Associated_Subprogram = 111
+    Subprogram_Specification = 112
+    Sequential_Statement_Chain = 113
+    Simultaneous_Statement_Chain = 114
+    Subprogram_Body = 115
+    Overload_Number = 116
+    Subprogram_Depth = 117
+    Subprogram_Hash = 118
+    Impure_Depth = 119
+    Return_Type = 120
+    Implicit_Definition = 121
+    Uninstantiated_Subprogram_Name = 122
+    Default_Value = 123
+    Deferred_Declaration = 124
+    Deferred_Declaration_Flag = 125
+    Shared_Flag = 126
+    Design_Unit = 127
+    Block_Statement = 128
+    Signal_Driver = 129
+    Declaration_Chain = 130
+    File_Logical_Name = 131
+    File_Open_Kind = 132
+    Element_Position = 133
+    Use_Clause_Chain = 134
+    Context_Reference_Chain = 135
+    Inherit_Spec_Chain = 136
+    Selected_Name = 137
+    Type_Declarator = 138
+    Complete_Type_Definition = 139
+    Incomplete_Type_Ref_Chain = 140
+    Associated_Type = 141
+    Enumeration_Literal_List = 142
+    Entity_Class_Entry_Chain = 143
+    Group_Constituent_List = 144
+    Unit_Chain = 145
+    Primary_Unit = 146
+    Identifier = 147
+    Label = 148
+    Return_Identifier = 149
+    Visible_Flag = 150
+    Range_Constraint = 151
+    Direction = 152
+    Left_Limit = 153
+    Right_Limit = 154
+    Left_Limit_Expr = 155
+    Right_Limit_Expr = 156
+    Parent_Type = 157
+    Simple_Nature = 158
+    Base_Nature = 159
+    Resolution_Indication = 160
+    Record_Element_Resolution_Chain = 161
+    Tolerance = 162
+    Plus_Terminal_Name = 163
+    Minus_Terminal_Name = 164
+    Plus_Terminal = 165
+    Minus_Terminal = 166
+    Magnitude_Expression = 167
+    Phase_Expression = 168
+    Power_Expression = 169
+    Simultaneous_Left = 170
+    Simultaneous_Right = 171
+    Text_File_Flag = 172
+    Only_Characters_Flag = 173
+    Is_Character_Type = 174
+    Nature_Staticness = 175
+    Type_Staticness = 176
+    Constraint_State = 177
+    Index_Subtype_List = 178
+    Index_Subtype_Definition_List = 179
+    Element_Subtype_Indication = 180
+    Element_Subtype = 181
+    Element_Subnature_Indication = 182
+    Element_Subnature = 183
+    Index_Constraint_List = 184
+    Array_Element_Constraint = 185
+    Has_Array_Constraint_Flag = 186
+    Has_Element_Constraint_Flag = 187
+    Elements_Declaration_List = 188
+    Owned_Elements_Chain = 189
+    Designated_Type = 190
+    Designated_Subtype_Indication = 191
+    Index_List = 192
+    Reference = 193
+    Nature_Declarator = 194
+    Across_Type_Mark = 195
+    Through_Type_Mark = 196
+    Across_Type_Definition = 197
+    Through_Type_Definition = 198
+    Across_Type = 199
+    Through_Type = 200
+    Target = 201
+    Waveform_Chain = 202
+    Guard = 203
+    Delay_Mechanism = 204
+    Reject_Time_Expression = 205
+    Force_Mode = 206
+    Has_Force_Mode = 207
+    Sensitivity_List = 208
+    Process_Origin = 209
+    Package_Origin = 210
+    Condition_Clause = 211
+    Break_Element = 212
+    Selector_Quantity = 213
+    Break_Quantity = 214
+    Timeout_Clause = 215
+    Postponed_Flag = 216
+    Callees_List = 217
+    Passive_Flag = 218
+    Resolution_Function_Flag = 219
+    Wait_State = 220
+    All_Sensitized_State = 221
+    Seen_Flag = 222
+    Pure_Flag = 223
+    Foreign_Flag = 224
+    Resolved_Flag = 225
+    Signal_Type_Flag = 226
+    Has_Signal_Flag = 227
+    Purity_State = 228
+    Elab_Flag = 229
+    Vendor_Library_Flag = 230
+    Configuration_Mark_Flag = 231
+    Configuration_Done_Flag = 232
+    Index_Constraint_Flag = 233
+    Hide_Implicit_Flag = 234
+    Assertion_Condition = 235
+    Report_Expression = 236
+    Severity_Expression = 237
+    Instantiated_Unit = 238
+    Instantiated_Header = 239
+    Generic_Map_Aspect_Chain = 240
+    Port_Map_Aspect_Chain = 241
+    Configuration_Name = 242
+    Component_Configuration = 243
+    Configuration_Specification = 244
+    Default_Binding_Indication = 245
+    Default_Configuration_Declaration = 246
+    Expression = 247
+    Conditional_Expression_Chain = 248
+    Allocator_Designated_Type = 249
+    Selected_Waveform_Chain = 250
+    Conditional_Waveform_Chain = 251
+    Guard_Expression = 252
+    Guard_Decl = 253
+    Guard_Sensitivity_List = 254
+    Attribute_Implicit_Chain = 255
+    Block_Block_Configuration = 256
+    Package_Header = 257
+    Block_Header = 258
+    Uninstantiated_Package_Name = 259
+    Uninstantiated_Package_Decl = 260
+    Associated_Package = 261
+    Instance_Source_File = 262
+    Generate_Block_Configuration = 263
+    Generate_Statement_Body = 264
+    Alternative_Label = 265
+    Generate_Else_Clause = 266
+    Condition = 267
+    Else_Clause = 268
+    Parameter_Specification = 269
+    Parent = 270
+    Loop_Label = 271
+    Exit_Flag = 272
+    Next_Flag = 273
+    Component_Name = 274
+    Instantiation_List = 275
+    Entity_Aspect = 276
+    Default_Entity_Aspect = 277
+    Binding_Indication = 278
+    Named_Entity = 279
+    Referenced_Name = 280
+    Expr_Staticness = 281
+    Scalar_Size = 282
+    Error_Origin = 283
+    Operand = 284
+    Left = 285
+    Right = 286
+    Unit_Name = 287
+    Name = 288
+    Group_Template_Name = 289
+    Name_Staticness = 290
+    Prefix = 291
+    Signature_Prefix = 292
+    External_Pathname = 293
+    Pathname_Suffix = 294
+    Pathname_Expression = 295
+    In_Formal_Flag = 296
+    Inertial_Flag = 297
+    Slice_Subtype = 298
+    Suffix = 299
+    Index_Subtype = 300
+    Parameter = 301
+    Parameter_2 = 302
+    Parameter_3 = 303
+    Parameter_4 = 304
+    Attr_Chain = 305
+    Attribute_Implicit_Declaration = 306
+    Actual_Type = 307
+    Actual_Type_Definition = 308
+    Association_Chain = 309
+    Individual_Association_Chain = 310
+    Subprogram_Association_Chain = 311
+    Aggregate_Info = 312
+    Sub_Aggregate_Info = 313
+    Aggr_Dynamic_Flag = 314
+    Aggr_Min_Length = 315
+    Aggr_Low_Limit = 316
+    Aggr_High_Limit = 317
+    Aggr_Others_Flag = 318
+    Aggr_Named_Flag = 319
+    Aggregate_Expand_Flag = 320
+    Determined_Aggregate_Flag = 321
+    Association_Choices_Chain = 322
+    Case_Statement_Alternative_Chain = 323
+    Matching_Flag = 324
+    Choice_Staticness = 325
+    Procedure_Call = 326
+    Implementation = 327
+    Parameter_Association_Chain = 328
+    Method_Object = 329
+    Subtype_Type_Mark = 330
+    Subnature_Nature_Mark = 331
+    Type_Conversion_Subtype = 332
+    Type_Mark = 333
+    File_Type_Mark = 334
+    Return_Type_Mark = 335
+    Has_Disconnect_Flag = 336
+    Has_Active_Flag = 337
+    Is_Within_Flag = 338
+    Type_Marks_List = 339
+    Implicit_Alias_Flag = 340
+    Alias_Signature = 341
+    Attribute_Signature = 342
+    Overload_List = 343
+    Simple_Name_Identifier = 344
+    Simple_Name_Subtype = 345
+    Protected_Type_Body = 346
+    Protected_Type_Declaration = 347
+    Use_Flag = 348
+    Elaborated_Flag = 349
+    End_Has_Reserved_Id = 350
+    End_Has_Identifier = 351
+    End_Has_Postponed = 352
+    Has_Label = 353
+    Has_Begin = 354
+    Has_End = 355
+    Has_Is = 356
+    Has_Pure = 357
+    Has_Body = 358
+    Has_Parameter = 359
+    Has_Component = 360
+    Has_Identifier_List = 361
+    Has_Mode = 362
+    Has_Class = 363
+    Has_Delay_Mechanism = 364
+    Suspend_Flag = 365
+    Stop_Flag = 366
+    Is_Ref = 367
+    Is_Forward_Ref = 368
+    Psl_Property = 369
+    Psl_Sequence = 370
+    Psl_Declaration = 371
+    Psl_Expression = 372
+    Psl_Boolean = 373
+    PSL_Clock = 374
+    PSL_NFA = 375
+    PSL_Nbr_States = 376
+    PSL_Clock_Sensitivity = 377
+    PSL_EOS_Flag = 378
+    PSL_Abort_Flag = 379
+    Count_Expression = 380
+    Clock_Expression = 381
+    Default_Clock = 382
+    Foreign_Node = 383
+    Suspend_State_Index = 384
+    Suspend_State_Chain = 385
+    Suspend_State_Last = 386
+    Suspend_State_Decl = 387
 
 
 def Get_Boolean(node, field):
@@ -929,6 +945,12 @@ def Has_Actual(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_open_actual")
+def Has_Open_Actual(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_actual_conversion")
 def Has_Actual_Conversion(kind: IirKind) -> bool:
@@ -1217,6 +1239,12 @@ def Has_Interface_Type_Subprograms(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_interface_type_definition")
+def Has_Interface_Type_Definition(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_nature_definition")
 def Has_Nature_Definition(kind: IirKind) -> bool:
@@ -1235,6 +1263,12 @@ def Has_Subnature_Indication(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_reference_terminal_flag")
+def Has_Reference_Terminal_Flag(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_mode")
 def Has_Mode(kind: IirKind) -> bool:
@@ -1265,6 +1299,18 @@ def Has_Interface_Declaration_Chain(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_default_subprogram")
+def Has_Default_Subprogram(kind: IirKind) -> bool:
+    """"""
+
+
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_associated_subprogram")
+def Has_Associated_Subprogram(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_subprogram_specification")
 def Has_Subprogram_Specification(kind: IirKind) -> bool:
@@ -1487,6 +1533,12 @@ def Has_Label(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_return_identifier")
+def Has_Return_Identifier(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_visible_flag")
 def Has_Visible_Flag(kind: IirKind) -> bool:
@@ -2021,6 +2073,12 @@ def Has_Instantiated_Unit(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_instantiated_header")
+def Has_Instantiated_Header(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_generic_map_aspect_chain")
 def Has_Generic_Map_Aspect_Chain(kind: IirKind) -> bool:
@@ -2112,8 +2170,8 @@ def Has_Guard_Sensitivity_List(kind: IirKind) -> bool:
 
 
 @export
-@BindToLibGHDL("vhdl__nodes_meta__has_signal_attribute_chain")
-def Has_Signal_Attribute_Chain(kind: IirKind) -> bool:
+@BindToLibGHDL("vhdl__nodes_meta__has_attribute_implicit_chain")
+def Has_Attribute_Implicit_Chain(kind: IirKind) -> bool:
     """"""
 
 
@@ -2147,6 +2205,12 @@ def Has_Uninstantiated_Package_Decl(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_associated_package")
+def Has_Associated_Package(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_instance_source_file")
 def Has_Instance_Source_File(kind: IirKind) -> bool:
@@ -2357,6 +2421,12 @@ def Has_In_Formal_Flag(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_inertial_flag")
+def Has_Inertial_Flag(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_slice_subtype")
 def Has_Slice_Subtype(kind: IirKind) -> bool:
@@ -2406,8 +2476,8 @@ def Has_Attr_Chain(kind: IirKind) -> bool:
 
 
 @export
-@BindToLibGHDL("vhdl__nodes_meta__has_signal_attribute_declaration")
-def Has_Signal_Attribute_Declaration(kind: IirKind) -> bool:
+@BindToLibGHDL("vhdl__nodes_meta__has_attribute_implicit_declaration")
+def Has_Attribute_Implicit_Declaration(kind: IirKind) -> bool:
     """"""
 
 
@@ -2495,6 +2565,12 @@ def Has_Aggregate_Expand_Flag(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_determined_aggregate_flag")
+def Has_Determined_Aggregate_Flag(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_association_choices_chain")
 def Has_Association_Choices_Chain(kind: IirKind) -> bool:
@@ -2657,6 +2733,12 @@ def Has_Use_Flag(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_elaborated_flag")
+def Has_Elaborated_Flag(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_end_has_reserved_id")
 def Has_End_Has_Reserved_Id(kind: IirKind) -> bool:
@@ -2753,6 +2835,12 @@ def Has_Suspend_Flag(kind: IirKind) -> bool:
     """"""
 
 
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_stop_flag")
+def Has_Stop_Flag(kind: IirKind) -> bool:
+    """"""
+
+
 @export
 @BindToLibGHDL("vhdl__nodes_meta__has_is_ref")
 def Has_Is_Ref(kind: IirKind) -> bool:
@@ -2853,3 +2941,27 @@ def Has_Default_Clock(kind: IirKind) -> bool:
 @BindToLibGHDL("vhdl__nodes_meta__has_foreign_node")
 def Has_Foreign_Node(kind: IirKind) -> bool:
     """"""
+
+
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_suspend_state_index")
+def Has_Suspend_State_Index(kind: IirKind) -> bool:
+    """"""
+
+
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_suspend_state_chain")
+def Has_Suspend_State_Chain(kind: IirKind) -> bool:
+    """"""
+
+
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_suspend_state_last")
+def Has_Suspend_State_Last(kind: IirKind) -> bool:
+    """"""
+
+
+@export
+@BindToLibGHDL("vhdl__nodes_meta__has_suspend_state_decl")
+def Has_Suspend_State_Decl(kind: IirKind) -> bool:
+    """"""
