@@ -39,7 +39,7 @@ SYMBOLS_MAP = {
     nodes.Iir_Kind.Variable_Declaration: {"kind": lsp.SymbolKind.Variable},
     nodes.Iir_Kind.Constant_Declaration: {"kind": lsp.SymbolKind.Constant},
     nodes.Iir_Kind.Signal_Declaration: {"kind": lsp.SymbolKind.Variable},
-    nodes.Iir_Kind.Signal_Attribute_Declaration: {"kind": None},
+    nodes.Iir_Kind.Attribute_Implicit_Declaration: {"kind": None},
     nodes.Iir_Kind.Interface_Variable_Declaration: {"kind": lsp.SymbolKind.Variable},
     nodes.Iir_Kind.Interface_Constant_Declaration: {"kind": lsp.SymbolKind.Constant},
     nodes.Iir_Kind.Interface_Signal_Declaration: {"kind": lsp.SymbolKind.Variable},
@@ -93,7 +93,7 @@ def get_symbols(fe, n):
         return get_symbols(fe, nodes.Get_Library_Unit(n))
     m = SYMBOLS_MAP.get(k, None)
     if m is None:
-        raise AssertionError("get_symbol: unhandled {}".format(pyutils.kind_image(k)))
+        raise AssertionError(f"get_symbol: unhandled {pyutils.kind_image(k)}")
     kind = m["kind"]
     if kind is None:
         return None
