@@ -46,6 +46,8 @@ class Workspace(object):
         errorout_memory.Install_Handler()
         flags.Flag_Elocations.value = True
         # flags.Verbose.value = True
+        # Gather comments
+        flags.Flag_Gather_Comments.value = True
         # We do analysis even in case of errors.
         parse.Flag_Parse_Parenthesis.value = True
         # Force analysis to get more feedback + navigation even in case
@@ -54,6 +56,7 @@ class Workspace(object):
         # Do not consider analysis order issues.
         flags.Flag_Elaborate_With_Outdated.value = True
         libghdl.errorout.Enable_Warning(errorout.Msgid.Warnid_Unused, True)
+        libghdl.errorout.Enable_Warning(errorout.Msgid.Warnid_No_Assoc, True)
         self.read_project()
         self.set_options_from_project()
         if libghdl.analyze_init_status() != 0:
@@ -95,7 +98,9 @@ class Workspace(object):
         # We assume the path is correct.
         path = lsp.path_from_uri(doc_uri)
         if source is None:
-            source = open(path).read()
+            source = open(path, "rb").read()
+        else:
+            source = source.encode(document.Document.encoding, "replace")
         sfe = document.Document.load(source, os.path.dirname(path), os.path.basename(path))
         return self._create_document(doc_uri, sfe)
 
@@ -151,11 +156,11 @@ class Workspace(object):
             absname = os.path.join(self._root_path, name)
         # Create a document for this file.
         try:
-            fd = open(absname)
+            fd = open(absname, "rb")
             sfe = document.Document.load(fd.read(), self._root_path, name)
             fd.close()
         except OSError as err:
-            self._server.show_message(lsp.MessageType.Error, "cannot load {}: {}".format(name, err.strerror))
+            self._server.show_message(lsp.MessageType.Error, f"cannot load {name}: {err.strerror}")
             return
         doc = self.create_document_from_sfe(sfe, absname)
         doc.parse_document()
@@ -170,7 +175,7 @@ class Workspace(object):
         except OSError as err:
             self._server.show_message(
                 lsp.MessageType.Error,
-                "cannot open project file {}: {}".format(prj_file, err.strerror),
+                f"cannot open project file {prj_file}: {err.strerror}",
             )
             return
         log.info("reading project file %s", prj_file)
@@ -180,7 +185,7 @@ class Workspace(object):
             log.info("error in project file")
             self._server.show_message(
                 lsp.MessageType.Error,
-                "json error in project file {}:{}:{}".format(prj_file, e.lineno, e.colno),
+                f"json error in project file {prj_file}:{e.lineno}:{e.colno}",
             )
         f.close()
 
@@ -201,9 +206,9 @@ class Workspace(object):
             log.info("Using options: %s", ghdl_opts)
             for opt in ghdl_opts:
                 if not libghdl.set_option(opt):
-                    self._server.show_message(lsp.MessageType.Error, "error with option: {}".format(opt))
+                    self._server.show_message(lsp.MessageType.Error, f"error with option: {opt}")
         except ProjectError as e:
-            self._server.show_message(lsp.MessageType.Error, "error in project file: {}".format(e.msg))
+            self._server.show_message(lsp.MessageType.Error, f"error in project file: {e.msg}")
 
     def read_files_from_project(self):
         try:
@@ -220,7 +225,7 @@ class Workspace(object):
                 if lang == "vhdl":
                     self.add_vhdl_file(name)
         except ProjectError as e:
-            self._server.show_message(lsp.MessageType.Error, "error in project file: {}".format(e.msg))
+            self._server.show_message(lsp.MessageType.Error, f"error in project file: {e.msg}")
 
     def get_configuration(self):
         self._server.configuration([{"scopeUri": "", "section": "vhdl.maxNumberOfProblems"}])
@@ -348,7 +353,8 @@ class Workspace(object):
         self._docs[doc_uri].check_document(source)
 
     def rm_document(self, doc_uri):
-        pass
+        # Clear diagnostics as it's not done automatically.
+        self.publish_diagnostics(doc_uri, [])
 
     def apply_edit(self, edit):
         return self._server.request("workspace/applyEdit", {"edit": edit})
@@ -382,18 +388,35 @@ class Workspace(object):
         return res
 
     def goto_definition(self, doc_uri, position):
-        decl = self._docs[doc_uri].goto_definition(position)
+        decl = self._docs[doc_uri].find_definition(position)
         if decl is None:
             return None
         decl_loc = self.declaration_to_location(decl)
         if decl_loc is None:
             return None
-        res = [decl_loc]
-        if nodes.Get_Kind(decl) == nodes.Iir_Kind.Component_Declaration:
+        return [decl_loc]
+
+    def goto_implementation(self, doc_uri, position):
+        decl = self._docs[doc_uri].find_definition(position)
+        if decl is None:
+            return None
+        k = nodes.Get_Kind(decl)
+        if k == nodes.Iir_Kind.Component_Declaration:
             ent = libraries.Find_Entity_For_Component(nodes.Get_Identifier(decl))
             if ent != nodes.Null_Iir:
-                res.append(self.declaration_to_location(nodes.Get_Library_Unit(ent)))
-        return res
+                decl = nodes.Get_Library_Unit(ent)
+        elif k in nodes.Iir_Kinds.Subprogram_Declaration:
+            bod = nodes.Get_Subprogram_Body(decl)
+            if bod != nodes.Null_Iir:
+                decl = bod
+
+        decl_loc = self.declaration_to_location(decl)
+        if decl_loc is None:
+            return None
+        return [decl_loc]
+
+    def hover(self, doc_uri, position):
+        return self._docs[doc_uri].hover(position)
 
     def x_show_all_files(self):
         res = []
@@ -472,12 +495,20 @@ class Workspace(object):
                         while lists.Is_Valid(byref(deps_it)):
                             el = lists.Get_Element(byref(deps_it))
                             if nodes.Get_Kind(el) == nodes.Iir_Kind.Design_Unit:
-                                if res.get(el, None):
-                                    res[el].append(units)
-                                else:
-                                    res[el] = [units]
+                                ent = el
+                            elif nodes.Get_Kind(el) == nodes.Iir_Kind.Entity_Aspect_Entity:
+                                # Extract design unit from entity aspect
+                                # Do not care about the architecture.
+                                ent = nodes.Get_Entity_Name(el)
+                                ent = nodes.Get_Named_Entity(ent)
+                                ent = nodes.Get_Design_Unit(ent)
                             else:
-                                assert False
+                                assert False, pyutils.kind_image(nodes.Get_Kind(el))
+                            assert nodes.Get_Kind(ent) == nodes.Iir_Kind.Design_Unit
+                            if res.get(ent, None):
+                                res[ent].append(units)
+                            else:
+                                res[ent] = [units]
                             lists.Next(byref(deps_it))
                     units = nodes.Get_Chain(units)
                 files = nodes.Get_Chain(files)
